@@ -1,6 +1,15 @@
+# -*- coding: utf-8 -*-
 from Globals import package_home
-from Products.CMFCore import utils, CMFCorePermissions, DirectoryView
-from Products.CMFPlone.PloneUtilities import ToolInit
+from Products.CMFCore import utils, DirectoryView
+# plone3.0から変ったみたい．
+try:
+    #plone2.5まで
+    from Products.CMFCore import CMFCorePermissions
+    from Products.CMFPlone.PloneUtilities import ToolInit
+except ImportError:
+    #plone3.0から
+    from Products.CMFCore import permissions as CMFCorePermissions
+    from Products.CMFPlone.utils import ToolInit
 from Products.Archetypes.public import *
 from Products.Archetypes import listTypes
 from Products.Archetypes.utils import capitalize
