@@ -1,4 +1,7 @@
-from Products.CMFCore.CMFCorePermissions import setDefaultRoles
+try:
+    from Products.CMFCore.CMFCorePermissions import setDefaultRoles
+except ImportError:
+    from Products.CMFCore.permissions import setDefaultRoles
 
 PROJECTNAME = "PGnuplot"
 DEFAULT_ADD_CONTENT_PERMISSION = "Add PGnuplot"
